@@ -23,17 +23,23 @@ import re
 
 # py2 vs py3 transition
 from ..six import text_type as unicode
-from ..six.moves.urllib.error import HTTPError
-
+from ..six.moves.urllib.parse import urlparse
 
 from .. import exceptions as exceptions
 from ..htmlcleanup import stripHTML
 
-from .base_adapter import BaseSiteAdapter,  makeDate
+from .base_adapter import BaseSiteAdapter
 
-ffnetgenres=["Adventure", "Angst", "Crime", "Drama", "Family", "Fantasy", "Friendship", "General",
-             "Horror", "Humor", "Hurt-Comfort", "Mystery", "Parody", "Poetry", "Romance", "Sci-Fi",
-             "Spiritual", "Supernatural", "Suspense", "Tragedy", "Western"]
+ffnetgenres=["Adventure", "Angst", "Crime", "Drama", "Family", "Fantasy",
+             "Friendship", "General", "Horror", "Humor", "Hurt-Comfort",
+             "Mystery", "Parody", "Poetry", "Romance", "Sci-Fi", "Spiritual",
+             "Supernatural", "Suspense", "Tragedy", "Western"]
+
+ffnetpluscategories=["+Anima", "Rosario + Vampire", "Blood+",
+                     "+C: Sword and Cornett", "Norn9 - ノルン+ノネット",
+                     "Haré+Guu/ジャングルはいつもハレのちグゥ", "Lost+Brain",
+                     "Wicked + The Divine", "Alex + Ada", "RE: Alistair++",
+                     "Tristan + Isolde"]
 
 class FanFictionNetSiteAdapter(BaseSiteAdapter):
 
@@ -41,20 +47,8 @@ class FanFictionNetSiteAdapter(BaseSiteAdapter):
         BaseSiteAdapter.__init__(self, config, url)
         self.story.setMetadata('siteabbrev','ffnet')
 
-        # get storyId from url--url validation guarantees second part is storyId
-        self.story.setMetadata('storyId',self.parsedUrl.path.split('/',)[2])
+        self.set_story_idurl(url)
 
-        # normalized story URL.
-        self._setURL("https://"+self.getSiteDomain()\
-                         +"/s/"+self.story.getMetadata('storyId')+"/1/")
-
-        # ffnet update emails have the latest chapter URL.
-        # Frequently, when they arrive, not all the servers have the
-        # latest chapter yet and going back to chapter 1 to pull the
-        # chapter list doesn't get the latest.  So save and use the
-        # original URL given to pull chapter list & metadata.
-        # Not used by plugin because URL gets normalized first for
-        # eliminating duplicate story urls.
         self.origurl = url
         if "https://m." in self.origurl:
             ## accept m(mobile)url, but use www.
@@ -72,24 +66,42 @@ class FanFictionNetSiteAdapter(BaseSiteAdapter):
     def getSiteExampleURLs(cls):
         return "https://www.fanfiction.net/s/1234/1/ https://www.fanfiction.net/s/1234/12/ http://www.fanfiction.net/s/1234/1/Story_Title http://m.fanfiction.net/s/1234/1/"
 
+    def set_story_idurl(self,url):
+        parsedUrl = urlparse(url)
+        pathparts = parsedUrl.path.split('/',)
+        self.story.setMetadata('storyId',pathparts[2])
+        self.urltitle='' if len(pathparts)<5 else pathparts[4]
+        # normalized story URL.
+        self._setURL("https://"+self.getSiteDomain()\
+                         +"/s/"+self.story.getMetadata('storyId')+"/1/"+self.urltitle)
+
+    ## here so getSiteURLPattern and get_section_url(class method) can
+    ## both use it.  Note adapter_fictionpresscom has one too.
+    @classmethod
+    def _get_site_url_pattern(cls):
+        return r"https?://(www|m)?\.fanfiction\.net/s/(?P<id>\d+)(/\d+)?(/(?P<title>[^/]+))?/?$"
+
+    @classmethod
+    def get_section_url(cls,url):
+        ## minimal URL used for section names in INI and reject list
+        ## for comparison
+        # logger.debug("pre--url:%s"%url)
+        m = re.match(cls._get_site_url_pattern(),url)
+        if m:
+            url = "https://"+cls.getSiteDomain()\
+                +"/s/"+m.group('id')+"/1/"
+        # logger.debug("post-url:%s"%url)
+        return url
+
     def getSiteURLPattern(self):
-        return r"https?://(www|m)?\.fanfiction\.net/s/\d+(/\d+)?(/|/[^/]+)?/?$"
+        return self._get_site_url_pattern()
 
-    def _fetchUrl(self,url,parameters=None,extrasleep=1.0,usecache=True):
-        ## ffnet(and, I assume, fpcom) tends to fail more if hit too
-        ## fast.  This is in additional to what ever the
-        ## slow_down_sleep_time setting is.
-        return BaseSiteAdapter._fetchUrl(self,url,
-                                         parameters=parameters,
-                                         extrasleep=extrasleep,
-                                         usecache=usecache)
-
-    def use_pagecache(self):
-        '''
-        adapters that will work with the page cache need to implement
-        this and change it to True.
-        '''
-        return True
+    ## not actually putting urltitle on multi-chapters below, but
+    ## one-shots will have it, so this is still useful.  normalized
+    ## chapter URLs do NOT contain the story title.
+    def normalize_chapterurl(self,url):
+        return re.sub(r"https?://(www|m)\.(?P<keep>fanfiction\.net/s/\d+/\d+/).*",
+                      r"https://www.\g<keep>",url)
 
     def doExtractChapterUrlsAndMetadata(self,get_cover=True):
 
@@ -99,16 +111,9 @@ class FanFictionNetSiteAdapter(BaseSiteAdapter):
         url = self.origurl
         logger.debug("URL: "+url)
 
-        # use BeautifulSoup HTML parser to make everything easier to find.
-        try:
-            data = self._fetchUrl(url)
-            #logger.debug("\n===================\n%s\n===================\n"%data)
-            soup = self.make_soup(data)
-        except HTTPError as e:
-            if e.code == 404:
-                raise exceptions.StoryDoesNotExist(url)
-            else:
-                raise e
+        data = self.get_request(url)
+        #logger.debug("\n===================\n%s\n===================\n"%data)
+        soup = self.make_soup(data)
 
         if "Unable to locate story" in data or "Story Not Found" in data:
             raise exceptions.StoryDoesNotExist(url)
@@ -118,6 +123,10 @@ class FanFictionNetSiteAdapter(BaseSiteAdapter):
         if "Please check to see you are not using an outdated url." in data:
             raise exceptions.FailedToDownload("Error downloading Chapter: %s!  'Chapter not found. Please check to see you are not using an outdated url.'" % url)
 
+        # <link rel="canonical" href="//www.fanfiction.net/s/13551154/100/Haze-Gray">
+        canonicalurl = soup.select_one('link[rel=canonical]')['href']
+        self.set_story_idurl(canonicalurl)
+
         if self.getConfig('check_next_chapter'):
             try:
                 ## ffnet used to have a tendency to send out update
@@ -130,21 +139,18 @@ class FanFictionNetSiteAdapter(BaseSiteAdapter):
                 # get chapter part of url.
                 except:
                     chapcount = 1
-                tryurl = "https://%s/s/%s/%d/"%(self.getSiteDomain(),
-                                                self.story.getMetadata('storyId'),
-                                                chapcount+1)
+                tryurl = "https://%s/s/%s/%d/%s"%(self.getSiteDomain(),
+                                                  self.story.getMetadata('storyId'),
+                                                  chapcount+1,
+                                                  self.urltitle)
                 logger.debug('=Trying newer chapter: %s' % tryurl)
-                newdata = self._fetchUrl(tryurl)
+                newdata = self.get_request(tryurl)
                 if "not found. Please check to see you are not using an outdated url." not in newdata \
                         and "This request takes too long to process, it is timed out by the server." not in newdata:
                     logger.debug('=======Found newer chapter: %s' % tryurl)
                     soup = self.make_soup(newdata)
-            except HTTPError as e:
-                if e.code == 503:
-                    raise e
             except Exception as e:
-                logger.warning("Caught an exception reading URL: %s Exception %s."%(unicode(url),unicode(e)))
-                pass
+                logger.warning("Caught exception in check_next_chapter URL: %s Exception %s."%(unicode(tryurl),unicode(e)))
 
         # Find authorid and URL from... author url.
         a = soup.find('a', href=re.compile(r"^/u/\d+"))
@@ -168,20 +174,17 @@ class FanFictionNetSiteAdapter(BaseSiteAdapter):
             # of Book, Movie, etc.
             self.story.addToList('category',stripHTML(categories[1]))
         elif 'Crossover' in categories[0]['href']:
-            caturl = "https://%s%s"%(self.getSiteDomain(),categories[0]['href'])
-            catsoup = self.make_soup(self._fetchUrl(caturl))
-            found = False
-            for a in catsoup.findAll('a',href=re.compile(r"^/crossovers/.+?/\d+/")):
-                self.story.addToList('category',stripHTML(a))
-                found = True
-            if not found:
-                # Fall back.  I ran across a story with a Crossver
-                # category link to a broken page once.
-                # http://www.fanfiction.net/s/2622060/1/
-                # Naruto + Harry Potter Crossover
-                logger.info("Fall back category collection")
-                for c in stripHTML(categories[0]).replace(" Crossover","").split(' + '):
-                    self.story.addToList('category',c)
+            ## turns out there's only a handful of ffnet category's
+            ## with '+' in.  Keep a list and look for them
+            ## specifically instead of looking up the crossover page.
+            crossover_cat = stripHTML(categories[0]).replace(" Crossover","")
+            for pluscat in ffnetpluscategories:
+                if pluscat in crossover_cat:
+                    self.story.addToList('category',pluscat)
+                    crossover_cat = crossover_cat.replace(pluscat,'')
+            for cat in crossover_cat.split(' + '):
+                if cat:
+                    self.story.addToList('category',cat)
 
         a = soup.find('a', href=re.compile(r'https?://www\.fictionratings\.com/'))
         rating = a.string
@@ -297,41 +300,44 @@ class FanFictionNetSiteAdapter(BaseSiteAdapter):
                     cover_url=img['src']
             ## Nov 19, 2020, ffnet lazy cover images returning 0 byte
             ## files.
-            logger.debug("cover_url:%s"%cover_url)
+            # logger.debug("cover_url:%s"%cover_url)
 
             authimg_url = ""
             if cover_url and self.getConfig('skip_author_cover'):
-                authsoup = self.make_soup(self._fetchUrl(self.story.getMetadata('authorUrl')))
                 try:
-                    img = authsoup.select_one('img.lazy.cimage')
-                    authimg_url=img['data-original']
-                except:
-                    img = authsoup.select_one('img.cimage')
-                    if img:
-                        authimg_url=img['src']
+                    authsoup = self.make_soup(self.get_request(self.story.getMetadata('authorUrl')))
+                    try:
+                        img = authsoup.select_one('img.lazy.cimage')
+                        authimg_url=img['data-original']
+                    except:
+                        img = authsoup.select_one('img.cimage')
+                        if img:
+                            authimg_url=img['src']
 
-                logger.debug("authimg_url:%s"%authimg_url)
+                    logger.debug("authimg_url:%s"%authimg_url)
 
-                ## ffnet uses different sizes on auth & story pages, but same id.
-                ## Old URLs:
-                ## //ffcdn2012t-fictionpressllc.netdna-ssl.com/image/1936929/150/
-                ## //ffcdn2012t-fictionpressllc.netdna-ssl.com/image/1936929/180/
-                ## After Dec 2020 ffnet changes:
-                ## /image/6472517/180/
-                ## /image/6472517/150/
-                try:
-                    cover_id = cover_url.split('/')[-3]
-                except:
-                    cover_id = None
-                try:
-                    authimg_id = authimg_url.split('/')[-3]
-                except:
-                    authimg_id = None
+                    ## ffnet uses different sizes on auth & story pages, but same id.
+                    ## Old URLs:
+                    ## //ffcdn2012t-fictionpressllc.netdna-ssl.com/image/1936929/150/
+                    ## //ffcdn2012t-fictionpressllc.netdna-ssl.com/image/1936929/180/
+                    ## After Dec 2020 ffnet changes:
+                    ## /image/6472517/180/
+                    ## /image/6472517/150/
+                    try:
+                        cover_id = cover_url.split('/')[-3]
+                    except:
+                        cover_id = None
+                    try:
+                        authimg_id = authimg_url.split('/')[-3]
+                    except:
+                        authimg_id = None
 
-                ## don't use cover if it matches the auth image.
-                if cover_id and authimg_id and cover_id == authimg_id:
-                    logger.debug("skip_author_cover: cover_url matches authimg_url: don't use")
-                    cover_url = None
+                    ## don't use cover if it matches the auth image.
+                    if cover_id and authimg_id and cover_id == authimg_id:
+                        logger.debug("skip_author_cover: cover_url matches authimg_url: don't use")
+                        cover_url = None
+                except Exception as e:
+                    logger.warning("Caught exception in skip_author_cover: %s."%unicode(e))
 
             if cover_url:
                 self.setCoverImage(url,cover_url)
@@ -359,10 +365,10 @@ class FanFictionNetSiteAdapter(BaseSiteAdapter):
 
     def getChapterText(self, url):
         logger.debug('Getting chapter text from: %s' % url)
-        ## ffnet(and, I assume, fpcom) tends to fail more if hit too
-        ## fast.  This is in additional to what ever the
-        ## slow_down_sleep_time setting is.
-        data = self._fetchUrl(url,extrasleep=4.0)
+
+        ## AND explicitly put title URL back on chapter URL for fetch
+        ## *only*--normalized chapter URL does NOT have urltitle
+        data = self.get_request(url+self.urltitle)
 
         if "Please email this error message in full to <a href='mailto:support@fanfiction.com'>support@fanfiction.com</a>" in data:
             raise exceptions.FailedToDownload("Error downloading Chapter: %s!  FanFiction.net Site Error!" % url)
