@@ -27,7 +27,6 @@ from .. import exceptions as exceptions
 # py2 vs py3 transition
 from ..six.moves.urllib.parse import urlparse, urlunparse
 from ..six import text_type as unicode
-from ..six.moves.urllib.error import HTTPError
 
 from .base_adapter import BaseSiteAdapter,  makeDate
 
@@ -118,14 +117,12 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
         ## and finestories.
 
         ## fetch 'v' code, post action and redirected domain from login page.
-        (data,opened) = self._fetchUrlOpened(loginUrl,
-                                             usecache=False)
+        (data,useurl) = self.get_request_redirected(loginUrl,usecache=False)
         # logger.debug(data)
         if not self.needToLoginCheck(data):
             ## hitting login URL reminds system we're logged in?
             logger.debug("don't need to login")
             return
-        useurl = opened.geturl()
         soup = self.make_soup(data)
         params = {}
         params['v']=soup.find('input', {'name':'v'})['value']
@@ -138,55 +135,20 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
                               parsedUrl.netloc,
                               postAction,
                               '','',''))
-        # try:
-        data = self._postUrl(postUrl,params,usecache=False)
-        # logger.debug(data)
-        # except HTTPError as e:
-        #     if e.code == 307:
-        #         logger.debug("HTTP Error 307: Temporary Redirect -- assumed to be valid login for this site")
-        #         return
+        data = self.post_request(postUrl,params,usecache=False)
 
         soup = self.make_soup(data)
         params['v']=soup.find('input', {'name':'v'})['value']
         params['password'] = password
         params['cmd'] = 'cred_set'
 
-        # postAction = soup.find('form')['action']
-
-        # parsedUrl = urlparse(useurl)
-        # postUrl = urlunparse(urlunparse(
-        #         (parsedUrl.scheme,
-        #          parsedUrl.netloc,
-        #          postAction,
-        #          '','',''))
-
-        try:
-            data = self._postUrl(postUrl,params,usecache=False)
-            # logger.debug(data)
-        except HTTPError as e:
-            if e.code == 307:
-                logger.debug("e Location:%s"%e.headers['Location'])
-                try:
-                    ## need to hit redirect URL so cookies get set for
-                    ## the story site domain.  I think.
-                    data = self._postUrl(e.headers['Location'],params,usecache=False)
-                except HTTPError as e:
-                    if e.code == 307:
-                        # logger.debug(e)
-                        return
+        data = self.post_request(postUrl,params,usecache=False)
 
         if self.needToLoginCheck(data):
             logger.info("Failed to login to URL %s as %s" % (loginUrl,
                                                               username))
             raise exceptions.FailedToLogin(url,username)
 
-    def use_pagecache(self):
-        '''
-        adapters that will work with the page cache need to implement
-        this and change it to True.
-        '''
-        return True
-
     ## Getting the chapter list and the meta data, plus 'is adult' checking.
     def doExtractChapterUrlsAndMetadata(self, get_cover=True):
 
@@ -196,12 +158,10 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
         logger.debug("URL: "+url)
 
         try:
-            data = self._fetchUrl(url+":i")
+            data = self.get_request(url+":i")
             # logger.debug(data)
-        except HTTPError as e:
-            if e.code == 404:
-                raise exceptions.StoryDoesNotExist("Code: %s: %s"%(e.code,self.url))
-            elif e.code in (401, 403, 410):
+        except exceptions.HTTPErrorFFF as e:
+            if e.status_code in (401, 403, 410):
                 data = 'Log In' # to trip needToLoginCheck
             else:
                 raise e
@@ -209,15 +169,7 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
         if self.needToLoginCheck(data):
             # need to log in for this one.
             self.performLogin(url)
-            try:
-                data = self._fetchUrl(url+":i",usecache=False)
-            except HTTPError as e:
-                if e.code in (404, 410):
-                    raise exceptions.StoryDoesNotExist("Code: %s: %s"%(e.code,self.url))
-                elif e.code == 401:
-                    data = ''
-                else:
-                    raise e
+            data = self.get_request(url+":i",usecache=False)
 
         if "Access denied. This story has not been validated by the adminstrators of this site." in data:
             raise exceptions.AccessDenied(self.getSiteDomain() +" says: Access denied. This story has not been validated by the adminstrators of this site.")
@@ -226,11 +178,9 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
         elif "Error! Daily Limit Reached" in data or "Sorry! You have reached your daily limit of" in data:
             raise exceptions.FailedToDownload(self.getSiteDomain() +" says: Error! Daily Limit Reached")
 
-        # use BeautifulSoup HTML parser to make everything easier to find.
         soup = self.make_soup(data)
         # logger.debug(data)
 
-        # Now go hunting for all the meta data and the chapter list.
 
         ## Title
         a = soup.find('h1')
@@ -334,11 +284,7 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
         story_found = False
         while not story_found:
             page = page + 1
-            try:
-                data = self._fetchUrl(self.story.getList('authorUrl')[0] + "/" + unicode(page))
-            except HTTPError as e:
-                if e.code == 404:
-                    raise exceptions.FailedToDownload("Story not found in Author's list--Set Access Level to Full Access and change Listings Theme back to "+self.getTheme())
+            data = self.get_request(self.story.getList('authorUrl')[0] + "/" + unicode(page))
             asoup = self.make_soup(data)
 
             story_row = asoup.find(row_class, {'id' : 'sr' + self.story.getMetadata('storyId')})
@@ -367,7 +313,7 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
                 self.story.setMetadata('seriesUrl',seriesUrl)
                 series_name = stripHTML(a)
                 # logger.debug("Series name= %s" % series_name)
-                series_soup = self.make_soup(self._fetchUrl(seriesUrl))
+                series_soup = self.make_soup(self.get_request(seriesUrl))
                 if series_soup:
                     # logger.debug("Retrieving Series - looking for name")
                     series_name = stripHTML(series_soup.find('h1', {'id' : 'ptitle'}))
@@ -377,7 +323,7 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
                 # Check if series is in a universe
                 if self.has_universes:
                     universe_url = self.story.getList('authorUrl')[0]  + "&type=uni"
-                    universes_soup = self.make_soup(self._fetchUrl(universe_url) )
+                    universes_soup = self.make_soup(self.get_request(universe_url) )
                     # logger.debug("Universe url='{0}'".format(universe_url))
                     if universes_soup:
                         universes = universes_soup.findAll('div', {'class' : 'ser-box'})
@@ -401,7 +347,6 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
                     #     logger.debug("No universe page")
         except:
             raise
-            pass
         try:
             a = description_element.find('a', href=re.compile(r"/universe/\d+/.*"))
             # logger.debug("Looking for universe - a='{0}'".format(a))
@@ -411,7 +356,7 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
                 universe_name = stripHTML(a)
                 universeUrl = 'https://'+self.host+a['href']
                 # logger.debug("Retrieving Universe - about to get page - universeUrl='{0}".format(universeUrl))
-                universe_soup = self.make_soup(self._fetchUrl(universeUrl))
+                universe_soup = self.make_soup(self.get_request(universeUrl))
                 # logger.debug("Retrieving Universe - have page")
                 if universe_soup:
                     # logger.debug("Retrieving Universe - looking for name")
@@ -434,7 +379,6 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
             #     logger.debug("Do not have a universe")
         except:
             raise
-            pass
 
         # There's nothing around the desc to grab it by, and there's a
         # variable number of links before it.
@@ -514,7 +458,7 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
 
         logger.debug('Getting chapter text from: %s' % url)
 
-        soup = self.make_soup(self._fetchUrl(url))
+        soup = self.make_soup(self.get_request(url))
 
         # The story text is wrapped in article tags. Most of the page header and
         # footer are outside of this.
@@ -533,7 +477,7 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
             pager.extract()
 
             for ur in urls:
-                soup = self.make_soup(self._fetchUrl("https://"+self.getSiteDomain()+ur['href']))
+                soup = self.make_soup(self.get_request("https://"+self.getSiteDomain()+ur['href']))
 
                 pagetag = soup.find('article')
 
