@@ -30,15 +30,12 @@ from __future__ import absolute_import
 import logging
 logger = logging.getLogger(__name__)
 import re
-import sys
 
 from bs4.element import Comment
 from ..htmlcleanup import stripHTML
 from .. import exceptions as exceptions
 
 # py2 vs py3 transition
-from ..six import text_type as unicode
-from ..six.moves.urllib.error import HTTPError
 
 from .base_adapter import BaseSiteAdapter, makeDate
 
@@ -82,6 +79,12 @@ class SugarQuillNetAdapter(BaseSiteAdapter):
     def getSiteURLPattern(self):
         return re.escape("http://"+self.getSiteDomain()+"/read.php?storyid=")+r"\d+"
 
+    @classmethod
+    def stripURLParameters(cls,url):
+        ## remove any parameters other than storyid.  chapno=1 will be
+        ## added to canonical storyUrl
+        return re.sub(r"\?.*(storyid=\d+).*$",r"?\1",url)
+
     ## Getting the chapter list and the meta data
     def extractChapterUrlsAndMetadata(self):
 
@@ -90,21 +93,13 @@ class SugarQuillNetAdapter(BaseSiteAdapter):
         url = self.url+'&chapno=1'
         logger.debug("URL: "+url)
 
-        try:
-            data = self._fetchUrl(url)
-        except HTTPError as e:
-            if e.code == 404:
-                raise exceptions.StoryDoesNotExist(url)
-            else:
-                raise e
+        data = self.get_request(url)
 
         if "Invalid storyid or chapno" in data:
             raise exceptions.AccessDenied(self.getSiteDomain() +" says: Invalid storyid or chapno.")
 
-        # use BeautifulSoup HTML parser to make everything easier to find.
         soup = self.make_soup(data)
 
-        # Now go hunting for all the meta data and the chapter list.
 
         ## Title
         a = soup.find('b',text='Story').nextSibling.string.strip(':').strip()
@@ -128,15 +123,7 @@ class SugarQuillNetAdapter(BaseSiteAdapter):
         ## The metadata is all on the author's page, so we have to get it to parse.
         author_Url = self.story.getMetadata('authorUrl').replace('&amp;','&')
         logger.debug('Getting the author page: {0}'.format(author_Url))
-        try:
-            adata = self._fetchUrl(author_Url)
-        except HTTPError as e:
-            if e.code in 404:
-                raise exceptions.StoryDoesNotExist("Author Page: Code: 404. {0}".format(author_Url))
-            elif e.code == 410:
-                raise exceptions.StoryDoesNotExist("Author Page: Code: 410. {0}".format(author_Url))
-            else:
-                raise e
+        adata = self.get_request(author_Url)
 
         if 'Invalid authorid' in adata:
             raise exceptions.StoryDoesNotExist('{0} says: Invalid authorid'.format(self.getSiteDomain()))
@@ -159,7 +146,7 @@ class SugarQuillNetAdapter(BaseSiteAdapter):
 
         logger.debug('Getting chapter text from: %s' % url)
 
-        soup = self.make_soup(self._fetchUrl(url))
+        soup = self.make_soup(self.get_request(url))
 
         chap = soup.find('td',{'class':'content_pane'})
 
