@@ -20,16 +20,13 @@ import logging
 from datetime import datetime
 logger = logging.getLogger(__name__)
 import re
-from xml.dom.minidom import parseString
 
 from ..htmlcleanup import stripHTML
 from .. import exceptions as exceptions
 
 # py2 vs py3 transition
 from ..six import text_type as unicode
-from ..six.moves.urllib.error import HTTPError
 
-from .base_adapter import makeDate
 from .base_xenforoforum_adapter import BaseXenForoForumAdapter
 
 logger = logging.getLogger(__name__)
@@ -63,7 +60,7 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
             raise exceptions.FailedToLogin(self.url,"No username given.  Set in personal.ini or enter when prompted.")
 
         ## need a login token.
-        data = self._fetchUrl(self.getURLPrefix() + 'login',usecache=False)
+        data = self.get_request(self.getURLPrefix() + 'login',usecache=False)
         # logger.debug(data)
         # <input type="hidden" name="_xfToken" value="1556822458,710e5bf6fc87c67ea04ab56a910ac3ff" />
         find_token='<input type="hidden" name="_xfToken" value="'
@@ -78,8 +75,7 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
         logger.debug("Will now login to URL (%s) as (%s)" % (loginUrl,
                                                              params['login']))
 
-        d = self._postUrl(loginUrl, params)# , headers={ 'referer':self.getURLPrefix() + '/login',
-                                           #            'origin':self.getURLPrefix() })
+        d = self.post_request(loginUrl, params)
 
         if "Log in" in d:
             # logger.debug(d)
