@@ -16,54 +16,35 @@
 #
 
 from __future__ import absolute_import
+import sys
 import re
 import codecs
-import random
 
 # py2 vs py3 transition
 from . import six
 from .six.moves import configparser
-from .six.moves.configparser import DEFAULTSECT, MissingSectionHeaderError, ParsingError
+from .six.moves.configparser import DEFAULTSECT, ParsingError
 if six.PY2:
     ConfigParser = configparser.SafeConfigParser
 else: # PY3
     ConfigParser = configparser.ConfigParser
 
-from .six.moves import urllib
-from .six.moves.urllib.parse import (urlencode, quote_plus)
-from .six.moves.urllib.request import (build_opener, HTTPCookieProcessor, Request)
-from .six.moves.urllib.error import HTTPError
-from .six.moves import http_cookiejar as cl
-from .six import text_type as unicode
 from .six import string_types as basestring
-from .six import ensure_binary, ensure_text
 
-import time
 import logging
-import sys
-import pickle
-
-## isn't found in plugin when only imported down below inside
-## get_scraper()
-import cloudscraper
-from cloudscraper.exceptions import CloudflareException
-
-from . import exceptions
-
 logger = logging.getLogger(__name__)
 
-## makes requests based(like cloudscraper) dump req/resp headers.
-## Does *not* work with older urllib code.
-# import http.client as http_client
-# http_client.HTTPConnection.debuglevel = 5
-
 try:
     import chardet
 except ImportError:
     chardet = None
 
-from .gziphttp import GZipProcessor
-from .htmlcleanup import reduce_zalgo
+from . import exceptions
+from . import fetcher
+
+## has to be up here for brotli-dict to load correctly.
+from .browsercache import BrowserCache
+
 
 # All of the writers(epub,html,txt) and adapters(ffnet,twlt,etc)
 # inherit from Configurable.  The config file(s) uses ini format:
@@ -80,6 +61,7 @@ from .htmlcleanup import reduce_zalgo
 # [overrides]
 # titlepage_entries: category
 
+
 # Work around for fact that py3 apparently doesn't allow/ignore
 # recursive imports like py2 does.
 try:
@@ -213,15 +195,23 @@ def get_valid_set_options():
 
                'use_ssl_unverified_context':(None,None,boollist),
                'use_cloudscraper':(None,None,boollist),
+               'use_basic_cache':(None,None,boollist),
+
+               ## currently, browser_cache_path is assumed to be
+               ## shared and only ffnet uses it so far
+               'browser_cache_path':(['defaults'],None,None),
+               'use_browser_cache':(['fanfiction.net'],None,boollist),
+               'use_browser_cache_only':(['fanfiction.net'],None,boollist),
+
                'continue_on_chapter_error':(None,None,boollist),
                'conditionals_use_lists':(None,None,boollist),
                'dedup_chapter_list':(None,None,boollist),
 
                'add_chapter_numbers':(None,None,boollist+['toconly']),
 
-               'check_next_chapter':(['fanfiction.net'],None,boollist),
-               'tweak_fg_sleep':(['fanfiction.net'],None,boollist),
-               'skip_author_cover':(['fanfiction.net'],None,boollist),
+               'check_next_chapter':(['fanfiction.net','fictionpress.com'],None,boollist),
+               'tweak_fg_sleep':(None,None,boollist),
+               'skip_author_cover':(['fanfiction.net','fictionpress.com'],None,boollist),
 
                'fix_fimf_blockquotes':(['fimfiction.net'],None,boollist),
                'fail_on_password':(['fimfiction.net'],None,boollist),
@@ -266,6 +256,7 @@ def get_valid_set_options():
                'windows_eol':(None,['txt'],boollist),
 
                'include_images':(None,['epub','html'],boollist),
+               'additional_images':(None,['epub','html'],None),
                'grayscale_images':(None,['epub','html'],boollist),
                'no_image_processing':(None,['epub','html'],boollist),
                'dedup_img_files':(None,['epub','html'],boollist),
@@ -408,6 +399,7 @@ def get_valid_keywords():
                  'grayscale_images',
                  'image_max_size',
                  'include_images',
+                 'additional_images',
                  'include_logpage',
                  'logpage_at_end',
                  'calibre_series_meta',
@@ -486,6 +478,11 @@ def get_valid_keywords():
                  'universe_as_series',
                  'use_ssl_unverified_context',
                  'use_cloudscraper',
+                 'use_basic_cache',
+                 'use_browser_cache',
+                 'use_browser_cache_only',
+                 'browser_cache_path',
+                 'browser_cache_age_limit',
                  'user_agent',
                  'username',
                  'website_encodings',
@@ -554,12 +551,20 @@ def make_generate_cover_settings(param):
 
 class Configuration(ConfigParser):
 
-    def __init__(self, sections, fileform, lightweight=False):
+    def __init__(self, sections, fileform, lightweight=False,
+                 basic_cache=None, browser_cache=None):
         site = sections[-1] # first section is site DN.
         ConfigParser.__init__(self)
 
+        self.fetcher = None # the network layer for getting pages the
+        self.sleeper = None
+        # caching layer for getting pages, create one if not given.
+        self.basic_cache = basic_cache or fetcher.BasicCache()
+        # don't create a browser cache by default.
+        self.browser_cache = browser_cache
+        self.opener = None # used for _filelist
+
         self.lightweight = lightweight
-        self.use_pagecache = False # default to false for old adapters.
 
         self.linenos=dict() # key by section or section,key -> lineno
 
@@ -597,19 +602,6 @@ class Configuration(ConfigParser):
 
         self.url_config_set = False
 
-        self.override_sleep = None
-        self.cookiejar = self.get_empty_cookiejar()
-        self.opener = build_opener(HTTPCookieProcessor(self.cookiejar),GZipProcessor())
-        self.scraper = None
-
-        self.pagecache = self.get_empty_pagecache()
-        self.save_cache_file = None
-        self.save_cookiejar_file = None
-
-    def __del__(self):
-        if self.scraper is not None:
-            self.scraper.close()
-
     def section_url_names(self,domain,section_url_f):
         ## domain is passed as a method to limit the damage if/when an
         ## adapter screws up _section_url
@@ -698,7 +690,7 @@ class Configuration(ConfigParser):
             val = ''
             for v in val_files:
                 try:
-                    val = val + self._fetchUrl(v)
+                    val = val + self._read_file_opener(v)
                     file_val = True
                 except:
                     pass
@@ -731,7 +723,6 @@ class Configuration(ConfigParser):
     def get_config_list(self, sections, key, default=[]):
         vlist = re.split(r'(?<!\\),',self.get_config(sections,key)) # don't split on \,
         vlist = [x for x in [ v.strip().replace(r'\,',',') for v in vlist ] if x !='']
-        #print("vlist("+key+"):"+unicode(vlist))
         if not vlist:
             return default
         else:
@@ -948,399 +939,119 @@ class Configuration(ConfigParser):
 
         return errors
 
+    def _read_file_opener(self,fn):
+        '''
+        For reading urls from _filelist entries.  Used to use same
+        fetch routines as for getting stories, but a) those make
+        dependencies a mess and b) that has a lot more complication
+        now with different caching.
+        '''
+
+        if not self.opener:
+            from .six.moves.urllib.request import build_opener
+            self.opener = build_opener()
+        # can't use with: structure in Cal v2.85.1
+        resp = self.opener.open(fn,None)
+        data = resp.read()
+        retval = None
+        for code in self.getConfigList('filelist_encodings',
+                                       default=["utf8",
+                                                "Windows-1252",
+                                                "iso-8859-1"]):
+            try:
+                retval = data.decode(code)
+                break
+            except:
+                logger.debug("failed decode (%s) as (%s)"%(fn,code))
+        resp.close()
+        return retval
+
 #### methods for fetching.  Moved here from base_adapter when
 #### *_filelist feature was added.
 
-    @staticmethod
-    def get_empty_cookiejar():
-        return cl.LWPCookieJar()
-
-    @staticmethod
-    def get_empty_pagecache():
-        return {}
-
-    def get_cookiejar(self):
-        return self.cookiejar
-
-    def set_cookiejar(self,cj,save_cookiejar_file=None):
-        self.cookiejar = cj
-        self.save_cookiejar_file = save_cookiejar_file
-        saveheaders = self.opener.addheaders
-        self.opener = build_opener(HTTPCookieProcessor(self.cookiejar),GZipProcessor())
-        self.opener.addheaders = saveheaders
-
-    def load_cookiejar(self,filename):
-        '''
-        Needs to be called after adapter create, but before any fetchs
-        are done.  Takes file *name*.
-        '''
-        self.get_cookiejar().load(filename, ignore_discard=True, ignore_expires=True)
-
-    def get_pagecache(self):
-        return self.pagecache
-
-    def set_pagecache(self,d,save_cache_file=None):
-        self.save_cache_file = save_cache_file
-        self.pagecache=d
-
-    def _get_cachekey(self, url, parameters=None, headers=None):
-        keylist=[url]
-        if parameters != None:
-            keylist.append('&'.join('{0}={1}'.format(key, val) for key, val in sorted(parameters.items())))
-        if headers != None:
-            keylist.append('&'.join('{0}={1}'.format(key, val) for key, val in sorted(headers.items())))
-        return unicode('?'.join(keylist))
-
-    def _has_cachekey(self,cachekey):
-        return self.use_pagecache and cachekey in self.get_pagecache()
-
-    def _get_from_pagecache(self,cachekey):
-        if self.use_pagecache:
-            return self.get_pagecache().get(cachekey)
-        else:
-            return None
-
-    def _set_to_pagecache(self,cachekey,data,redirectedurl):
-        if self.use_pagecache:
-            self.get_pagecache()[cachekey] = (data,ensure_text(redirectedurl))
-            if self.save_cache_file:
-                with open(self.save_cache_file,'wb') as jout:
-                    pickle.dump(self.get_pagecache(),jout,protocol=2)
-            if self.save_cookiejar_file:
-                self.get_cookiejar().save(self.save_cookiejar_file)
-
-## website encoding(s)--in theory, each website reports the character
-## encoding they use for each page.  In practice, some sites report it
-## incorrectly.  Each adapter has a default list, usually "utf8,
-## Windows-1252" or "Windows-1252, utf8".  The special value 'auto'
-## will call chardet and use the encoding it reports if it has +90%
-## confidence.  'auto' is not reliable.  1252 is a superset of
-## iso-8859-1.  Most sites that claim to be iso-8859-1 (and some that
-## claim to be utf8) are really windows-1252.
-    def _decode(self,data):
-        if not hasattr(data,'decode'):
-            ## py3 str() from pickle doesn't have .decode and is
-            ## already decoded.
-            return data
-        decode = self.getConfigList('website_encodings',
-                                    default=["utf8",
-                                             "Windows-1252",
-                                             "iso-8859-1"])
-        for code in decode:
-            try:
-                logger.debug("Encoding:%s"%code)
-                errors=None
-                if ':' in code:
-                    (code,errors)=code.split(':')
-                if code == "auto":
-                    if not chardet:
-                        logger.info("chardet not available, skipping 'auto' encoding")
-                        continue
-                    detected = chardet.detect(data)
-                    #print(detected)
-                    if detected['confidence'] > float(self.getConfig("chardet_confidence_limit",0.9)):
-                        logger.debug("using chardet detected encoding:%s(%s)"%(detected['encoding'],detected['confidence']))
-                        code=detected['encoding']
-                    else:
-                        logger.debug("chardet confidence too low:%s(%s)"%(detected['encoding'],detected['confidence']))
-                        continue
-                if errors == 'ignore': # only allow ignore.
-                    return data.decode(code,errors='ignore')
-                else:
-                    return data.decode(code)
-            except Exception as e:
-                logger.debug("code failed:"+code)
-                logger.debug(e)
-                pass
-        logger.info("Could not decode story, tried:%s Stripping non-ASCII."%decode)
-        try:
-            # python2
-            return "".join([x for x in data if ord(x) < 128])
-        except TypeError:
-            # python3
-            return "".join([chr(x) for x in data if x < 128])
-
-    def _progressbar(self):
-        if self.getConfig('progressbar'):
-            sys.stdout.write('.')
-            sys.stdout.flush()
-
-    def _do_reduce_zalgo(self,data):
-        max_zalgo = int(self.getConfig('max_zalgo',-1))
-        if max_zalgo > -1:
-            logger.debug("Applying max_zalgo:%s"%max_zalgo)
-            try:
-                return reduce_zalgo(data,max_zalgo)
-            except Exception as e:
-                logger.warning("reduce_zalgo failed(%s), continuing."%e)
-        return data
-
-    def get_scraper(self):
-        if not self.scraper:
-            ## ffnet adapter can't parse mobile output, so we only
-            ## want desktop browser.  But cloudscraper then insists on
-            ## a browser and platform, too.
-            self.scraper = cloudscraper.CloudScraper(browser={
-                    'browser': 'chrome',
-                    'platform': 'windows',
-                    'mobile': False,
-                    'desktop': True,
-                    })
-            ## CloudScraper is subclass of requests.Session.
-            ## probably need import higher up if ever used.
-            # import requests
-            # self.scraper = requests.Session()
-            self.scraper.cookies = self.cookiejar
-        return self.scraper
-
-    # Assumes application/x-www-form-urlencoded.  parameters, headers are dict()s
-    def _postUrl(self, url,
-                 parameters={},
-                 headers={},
-                 extrasleep=None,
-                 usecache=True):
-        '''
-        When should cache be cleared or not used? logins...
-
-        extrasleep is primarily for ffnet adapter which has extra
-        sleeps.  Passed into fetchs so it can be bypassed when
-        cache hits.
-        '''
-        url = quote_plus(ensure_binary(url),safe=';/?:@&=+$,%&#')
-
-        if self.getConfig('force_https'): ## For developer testing only.
-            url = url.replace("http:","https:")
-        cachekey=self._get_cachekey(url, parameters, headers)
-        if usecache and self._has_cachekey(cachekey) and not cachekey.startswith('file:'):
-            logger.debug("#####################################\npagecache(POST) HIT: %s"%safe_url(cachekey))
-            data,redirecturl = self._get_from_pagecache(cachekey)
-            return data
-
-        logger.debug("#####################################\npagecache(POST) MISS: %s"%safe_url(cachekey))
-        if not cachekey.startswith('file:'): # don't sleep for file: URLs.
-            self.do_sleep(extrasleep)
-
-        ## Request assumes POST when data!=None.  Also assumes data
-        ## is application/x-www-form-urlencoded.
-        if 'Content-type' not in headers:
-            headers['Content-type']='application/x-www-form-urlencoded'
-        if 'Accept' not in headers:
-            headers['Accept']="text/html,*/*"
-
-        # logger.debug("POST http login for SB xf2test %s"%url)
-        # if "xf2test" in url:
-        #     import base64
-        #     base64string = base64.encodestring(b"sbreview2019:Fs2PwuVE9").replace(b'\n', b'')
-        #     headers['Authorization']=b"Basic %s" % base64string
-        #     logger.debug("http login for SB xf2test")
-
-        if self.getConfig('use_cloudscraper',False):
-            logger.debug("Using cloudscraper for POST")
-            try:
-                resp = self.get_scraper().post(url,
-                                               headers=dict(headers),
-                                               data=parameters)
-                logger.debug("response code:%s"%resp.status_code)
-                resp.raise_for_status() # raises HTTPError if error code.
-                data = resp.content
-            except CloudflareException as e:
-                msg = unicode(e).replace(' in the opensource (free) version','...')
-                raise exceptions.FailedToDownload('cloudscraper reports: "%s"'%msg)
-        else:
-            req = Request(url,
-                          data=ensure_binary(urlencode(parameters)),
-                          headers=headers)
-
-            ## Specific UA because too many sites are blocking the default python UA.
-            self.opener.addheaders = [('User-Agent', self.getConfig('user_agent')),
-                                      ('X-Clacks-Overhead','GNU Terry Pratchett')]
-
-            data = self.opener.open(req,None,float(self.getConfig('connect_timeout',30.0))).read()
-        data = self._do_reduce_zalgo(self._decode(data))
-        self._progressbar()
-        ## postURL saves data to the pagecache *after* _decode() while
-        ## fetchRaw saves it *before* _decode()--because raw.
-        self._set_to_pagecache(cachekey,data,url)
-        return data
-
-    def _fetchUrl(self, url,
-                  parameters=None,
-                  usecache=True,
-                  extrasleep=None):
-        return self._fetchUrlOpened(url,
-                                    parameters,
-                                    usecache,
-                                    extrasleep)[0]
-
-    def _fetchUrlRawOpened(self, url,
-                           parameters=None,
-                           extrasleep=None,
-                           usecache=True,
-                           referer=None):
-        '''
-        When should cache be cleared or not used? logins...
-
-        extrasleep is primarily for ffnet adapter which has extra
-        sleeps.  Passed into fetchs so it can be bypassed when
-        cache hits.
-        '''
-        if parameters is None:
-            method='GET'
-        else:
-            method='GET-POST'
-        class FakeOpened:
-            def __init__(self,data,url):
-                self.data=data
-                self.url=url
-            def geturl(self): return self.url
-            def read(self): return self.data
-
-        if not url.startswith('file:'): # file fetches fail on + for space
-            url = quote_plus(ensure_binary(url),safe=';/?:@&=+$,%&#')
-
-        if self.getConfig('force_https'): ## For developer testing only.
-            url = url.replace("http:","https:")
-        cachekey=self._get_cachekey(url, parameters)
-        if usecache and self._has_cachekey(cachekey) and not cachekey.startswith('file:'):
-            logger.debug("#####################################\npagecache(%s) HIT: %s"%(method,safe_url(cachekey)))
-            data,redirecturl = self._get_from_pagecache(cachekey)
-            return (data,FakeOpened(data,redirecturl))
-
-        logger.debug("#####################################\npagecache(%s) MISS: %s"%(method,safe_url(cachekey)))
-        # print(self.get_pagecache().keys())
-        if not cachekey.startswith('file:'): # don't sleep for file: URLs.
-            self.do_sleep(extrasleep)
-
-        ## Specific UA because too many sites are blocking the default python UA.
-        headers = [('User-Agent', self.getConfig('user_agent')),
-                   ## starslibrary.net throws a "HTTP Error 403: Bad
-                   ## Behavior" over the X-Clacks-Overhead.  Which
-                   ## both against standard and rather a dick-move.
-                   #('X-Clacks-Overhead','GNU Terry Pratchett'),
-                   ]
-        if referer:
-            ## hpfanficarchive.com complains about Referer: None.
-            ## Could have defaulted to "" instead, but this way it's
-            ## not present at all
-            headers.append(('Referer',referer))
-
-        # logger.debug("GET http login for SB xf2test %s"%url)
-        # if "xf2test" in url:
-        #     import base64
-        #     base64string = base64.encodestring(b"sbreview2019:Fs2PwuVE9").replace(b'\n', b'')
-        #     headers.append(('Authorization',b"Basic %s" % base64string))
-        #     logger.debug("http login for SB xf2test")
-
-        self.opener.addheaders = headers
-
-        if self.getConfig('use_cloudscraper',False):
-            ## requests / cloudscraper wants a dict() for headers, not
-            ## list of tuples.
-            headers = dict(headers)
-            ## let cloudscraper do its thing with UA.
-            if 'User-Agent' in headers:
-                del headers['User-Agent']
-            if parameters != None:
-                logger.debug("Using cloudscraper for fetch POST")
-                resp = self.get_scraper().post(url,
-                                               headers=headers,
-                                               data=parameters)
+    def get_fetcher(self,
+                    make_new = False):
+        cookiejar = None
+        if self.fetcher is not None and make_new:
+            cookiejar = self.get_fetcher().get_cookiejar()
+            # save and re-apply cookiejar when make_new.
+        if not self.fetcher or make_new:
+            logger.debug("use_cloudscraper:%s"%self.getConfig('use_cloudscraper'))
+            if self.getConfig('use_cloudscraper',False):
+                fetchcls = fetcher.CloudScraperFetcher
             else:
-                logger.debug("Using cloudscraper for GET")
-                resp = self.get_scraper().get(url,
-                                              headers=headers)
-            logger.debug("response code:%s"%resp.status_code)
-            resp.raise_for_status() # raises HTTPError if error code.
-            data = resp.content
-            opened = FakeOpened(data,resp.url)
-        else:
-            ## opener.open() will to POST with params(data) and GET without.
-            if parameters != None:
-                opened = self.opener.open(url,
-                                          ensure_binary(urlencode(parameters)),
-                                          float(self.getConfig('connect_timeout',30.0)))
-            else:
-                opened = self.opener.open(url,
-                                          None,
-                                          float(self.getConfig('connect_timeout',30.0)))
-            data = opened.read()
-        self._progressbar()
-        ## postURL saves data to the pagecache *after* _decode() while
-        ## fetchRaw saves it *before* _decode()--because raw.
-        self._set_to_pagecache(cachekey,data,opened.url)
+                fetchcls = fetcher.RequestsFetcher
+            self.fetcher = fetchcls(self.getConfig,
+                                    self.getConfigList)
 
-        return (data,opened)
+            ########################################################
+            ## Adding fetcher decorators.  Order matters--last added,
+            ## first called.  If ProgressBarDecorator is added before
+            ## Cache, it's never called for cache hits, for example.
 
-    def set_sleep(self,val):
-        logger.debug("\n===========\n set sleep time %s\n==========="%val)
-        self.override_sleep = val
+            ## doesn't sleep when fromcache==True
+            ## saved for set_sleep
+            self.sleeper = fetcher.SleepDecorator()
+            self.sleeper.decorate_fetcher(self.fetcher)
 
-    def do_sleep(self,extrasleep=None):
-        if extrasleep:
-            logger.debug("extra sleep:%s"%extrasleep)
-            time.sleep(float(extrasleep))
-        t = None
-        if self.override_sleep:
-            t = float(self.override_sleep)
-        elif self.getConfig('slow_down_sleep_time'):
-            t = float(self.getConfig('slow_down_sleep_time'))
-        ## sleep randomly between 0.5 time and 1.5 time.
-        ## So 8 would be between 4 and 12.
-        if t:
-            rt = random.uniform(t*0.5, t*1.5)
-            logger.debug("random sleep(%0.2f-%0.2f):%0.2f"%(t*0.5, t*1.5,rt))
-            time.sleep(rt)
-
-    # parameters is a dict()
-    def _fetchUrlOpened(self, url,
-                        parameters=None,
-                        usecache=True,
-                        extrasleep=None,
-                        referer=None):
-
-        excpt=None
-        if url.startswith("file://"):
-            # only one try for file:s.
-            sleeptimes = [0]
-        else:
-            sleeptimes = [0, 2, 7, 12]
-        for sleeptime in sleeptimes:
-            if sleeptime:
-                logger.debug("retry sleep:%s"%sleeptime)
-            time.sleep(sleeptime)
-            try:
-                (data,opened)=self._fetchUrlRawOpened(url,
-                                                      parameters=parameters,
-                                                      usecache=usecache,
-                                                      extrasleep=extrasleep,
-                                                      referer=referer)
-                return (self._do_reduce_zalgo(self._decode(data)),opened)
-            except HTTPError as he:
-                excpt=he
-                if he.code in (403,404,410):
-                    logger.debug("Caught an exception reading URL: %s  Exception %s."%(unicode(safe_url(url)),unicode(he)))
-                    break # break out on 404
-                ## trekfanfiction.net has started returning the page,
-                ## but with a 500 code.  We can use the HTTPError as
-                ## the 'opened' in such case.
-                if he.code == 500 and 'trekfanfiction.net' in url:
-                    data = he.read()
-                    return (self._do_reduce_zalgo(self._decode(data)),he)
-            except Exception as e:
-                excpt=e
-                logger.debug("Caught an exception reading URL: %s sleeptime(%s) Exception %s."%(unicode(safe_url(url)),sleeptime,unicode(e)))
-                if isinstance(e,CloudflareException):
-                    ## cloudscraper exception messages can appear to
-                    ## come from FFF and cause confusion.
-                    msg = unicode(e).replace(' in the opensource (free) version','...')
-                    raise exceptions.FailedToDownload('cloudscraper reports: "%s"'%msg)
-                else:
+            ## cache decorator terminates the chain when found.
+            logger.debug("use_browser_cache:%s"%self.getConfig('use_browser_cache'))
+            if self.getConfig('use_browser_cache'):
+                logger.debug("browser_cache_path:%s"%self.getConfig('browser_cache_path'))
+                try:
+                    ## make a data list of decorators to re-apply if
+                    ## there are many more.
+                    if self.browser_cache is None:
+                        self.browser_cache = BrowserCache(self.getConfig("browser_cache_path"),
+                                                          age_limit=self.getConfig("browser_cache_age_limit"))
+                    fetcher.BrowserCacheDecorator(self.browser_cache).decorate_fetcher(self.fetcher)
+                except Exception as e:
+                    logger.warn("Failed to setup BrowserCache(%s)"%e)
                     raise
+            ## cache decorator terminates the chain when found.
+            logger.debug("use_basic_cache:%s"%self.getConfig('use_basic_cache'))
+            if self.getConfig('use_basic_cache') and self.basic_cache is not None:
+                fetcher.BasicCacheDecorator(self.basic_cache).decorate_fetcher(self.fetcher)
 
-        logger.debug("Giving up on %s" %safe_url(url))
-        logger.debug(excpt, exc_info=True)
-        raise(excpt)
+            if self.getConfig('progressbar'):
+                fetcher.ProgressBarDecorator().decorate_fetcher(self.fetcher)
+        if cookiejar is not None:
+            self.fetcher.set_cookiejar(cookiejar)
+        return self.fetcher
 
+    ## used by plugin to change time for ffnet.
+    def set_sleep_override(self,val):
+        return self.sleeper.set_sleep_override(val)
+
+    def get_cookiejar(self,filename=None):
+        return self.get_fetcher().get_cookiejar(filename)
+
+    def set_cookiejar(self,cookiejar):
+        self.get_fetcher().set_cookiejar(cookiejar)
+
+    def get_basic_cache(self):
+        return self.basic_cache
+
+    ## replace cache, then replace fetcher (while keeping cookiejar)
+    ## to replace fetcher decorators.
+    def set_basic_cache(self,cache):
+        self.basic_cache = cache
+        self.get_fetcher(make_new=True)
+
+    def get_browser_cache(self):
+        logger.debug("1configuration.get_browser_cache:%s"%self.browser_cache)
+        if self.browser_cache is None:
+            # force generation of browser cache if not there
+            self.get_fetcher()
+        logger.debug("2configuration.get_browser_cache:%s"%self.browser_cache)
+        return self.browser_cache
+
+    ## replace cache, then replace fetcher (while keeping cookiejar)
+    ## to replace fetcher decorators.
+    def set_browser_cache(self,cache):
+        self.browser_cache = cache
+        logger.debug("configuration.set_browser_cache:%s"%self.browser_cache)
+        self.get_fetcher(make_new=True)
 
 # extended by adapter, writer and story for ease of calling configuration.
 class Configurable(object):
@@ -1348,11 +1059,6 @@ class Configurable(object):
     def __init__(self, configuration):
         self.configuration = configuration
 
-        ## use_pagecache() is on adapters--not all have been updated
-        ## to deal with caching correctly
-        if hasattr(self, 'use_pagecache'):
-            self.configuration.use_pagecache = self.use_pagecache()
-
     def section_url_names(self,domain,section_url_f):
         return self.configuration.section_url_names(domain,section_url_f)
 
@@ -1401,69 +1107,3 @@ class Configurable(object):
             label=entry.title()
         return label
 
-    def do_sleep(self,extrasleep=None):
-        return self.configuration.do_sleep(extrasleep)
-
-    def set_decode(self,decode):
-        self.configuration.decode = decode
-
-    def _postUrl(self, url,
-                 parameters={},
-                 headers={},
-                 extrasleep=None,
-                 usecache=True):
-        return self.configuration._postUrl(url,
-                                           parameters,
-                                           headers,
-                                           extrasleep,
-                                           usecache)
-
-    def _fetchUrlRawOpened(self, url,
-                           parameters=None,
-                           extrasleep=None,
-                           usecache=True,
-                           referer=None):
-        return self.configuration._fetchUrlRawOpened(url,
-                                                     parameters,
-                                                     extrasleep,
-                                                     usecache,
-                                                     referer=referer)
-
-    def _fetchUrlOpened(self, url,
-                        parameters=None,
-                        usecache=True,
-                        extrasleep=None,
-                        referer=None):
-        return self.configuration._fetchUrlOpened(url,
-                                                  parameters,
-                                                  usecache,
-                                                  extrasleep,
-                                                  referer=referer)
-
-    def _fetchUrl(self, url,
-                  parameters=None,
-                  usecache=True,
-                  extrasleep=None,
-                  referer=None):
-        return self._fetchUrlOpened(url,
-                                    parameters,
-                                    usecache,
-                                    extrasleep,
-                                    referer=referer)[0]
-    def _fetchUrlRaw(self, url,
-                     parameters=None,
-                     extrasleep=None,
-                     usecache=True,
-                     referer=None):
-        return self._fetchUrlRawOpened(url,
-                                       parameters,
-                                       extrasleep,
-                                       usecache,
-                                       referer=referer)[0]
-
-
-# .? for AO3's ']' in param names.
-safe_url_re = re.compile(r'(?P<attr>(pass(word)?|name|login).?=)[^&]*(?P<amp>&|$)',flags=re.MULTILINE)
-def safe_url(url):
-    # return url with password attr (if present) obscured.
-    return re.sub(safe_url_re,r'\g<attr>XXXXXXXX\g<amp>',url)
